@@ -32,3 +32,8 @@ def clear_cache(cache_dir="__pycache__"):
             print(f"Lỗi khi xóa bộ nhớ đệm: {str(e)}")
     else:
         print(f"\nKhông còn bộ nhớ đệm.")
+
+def clear_cache_and_exit(cache_dir):
+    if os.path.exists(cache_dir):
+        shutil.rmtree(cache_dir)
+    print("Hẹn gặp lại!!!")
\ No newline at end of file
