@@ -1,5 +1,5 @@
 import cv2
-from .constants import FRAME_COLOR, TEXT_COLOR
+from .constants import TEXT_COLOR
 
 def display_tracking_id_on_frame(frame, tracking_id):
     """
